@@ -380,6 +380,7 @@ class TrustDomain {
 };
 
 enum class FallBackToSearchWithinSubject { No = 0, Yes = 1 };
+enum class HandleInvalidSubjectAlternativeNamesBy { Halting = 0, Skipping = 1 };
 
 // Applications control the behavior of matching presented name information from
 // a certificate against a reference hostname by implementing the
@@ -395,6 +396,9 @@ class NameMatchingPolicy {
       Time notBefore,
       /*out*/ FallBackToSearchWithinSubject& fallBackToCommonName) = 0;
 
+  virtual HandleInvalidSubjectAlternativeNamesBy
+  HandleInvalidSubjectAlternativeNames() = 0;
+
  protected:
   NameMatchingPolicy() {}
 
@@ -403,13 +407,15 @@ class NameMatchingPolicy {
 };
 
 class StrictNameMatchingPolicy : public NameMatchingPolicy {
-  public:
-    virtual Result FallBackToCommonName(
-        Time notBefore,
-        /*out*/ FallBackToSearchWithinSubject& fallBacktoCommonName) override;
-};
+ public:
+  virtual Result FallBackToCommonName(
+      Time notBefore,
+      /*out*/ FallBackToSearchWithinSubject& fallBacktoCommonName) override;
 
-}
-}  // namespace mozilla::pkix
+  virtual HandleInvalidSubjectAlternativeNamesBy
+  HandleInvalidSubjectAlternativeNames() override;
+};
+}  // namespace pkix
+}  // namespace mozilla
 
 #endif  // mozilla_pkix_pkixtypes_h
